@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,6 +27,10 @@ namespace KPIMTextEdit {
 class RichTextComposer;
 class NestedListHelper;
 class RichTextComposerImages;
+/**
+ * @brief The RichTextComposerControler class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class KPIMTEXTEDIT_EXPORT RichTextComposerControler : public QObject
 {
     Q_OBJECT
@@ -62,6 +66,7 @@ public:
     Q_REQUIRED_RESULT QString toWrappedPlainText(QTextDocument *doc) const;
     Q_REQUIRED_RESULT QString toWrappedPlainText() const;
     Q_REQUIRED_RESULT QString toCleanPlainText(const QString &plainText = QString()) const;
+    void addQuotes(const QString &defaultQuote);
 public Q_SLOTS:
     void insertHorizontalRule();
     void alignLeft();
